flutter_scalable library
Classes
- FlutterScalable
- Usage: Wrap MaterialApp with this widget
- Sp
- Scaler allows you to set the width and height of the widget in percentage You can set the width of the Widget in the range of ( 0 to 1 ) 0.5 represent the 5% 1.5 represent the 15% same as above you have to set its value between ( 0 to 1 ) to set in percentage
- SpacerUtil
Extensions
Typedefs
- ResponsiveBuild = Widget Function(BuildContext context)
-
Provides
Contextto the builder function